Class: Ruleby::Core::RulebyConflictResolver
- Inherits:
-
Object
- Object
- Ruleby::Core::RulebyConflictResolver
- Defined in:
- lib/core/engine.rb
Overview
A conflict resolver is used to order activations that become active at the same time. The default implementation sorts the agenda based on the properties of the activation.
Instance Method Summary collapse
Instance Method Details
#resolve(agenda) ⇒ Object
134 135 136 |
# File 'lib/core/engine.rb', line 134 def resolve(agenda) return agenda.sort end |